@@ -323,7 +323,7 @@ kernel_setup() {
     log_write 3 "  Make params: $MAKEPARAMS"
 
     if ! make $MAKEPARAMS \
-	           2>>$MAINLOGDIR/stderr.log >>$MAINLOGDIR/stdout.log
+	           2>>$LOGDIR/stderr.log >>$LOGDIR/stdout.log
     then
       log_error "Kernel prepare failed"
       return 1
@@ -340,7 +340,7 @@ kernel_setup() {
 
     log_write 3 "  Make params: $MAKEPARAMS"
     if ! make $MAKEPARAMS \
-                2>>$MAINLOGDIR/stderr.log >>$MAINLOGDIR/stdout.log
+                2>>$LOGDIR/stderr.log >>$LOGDIR/stdout.log
     then
       if test "x$1" = "xfull"
       then
@@ -444,7 +444,7 @@ dummy_glibc_objects() {
        return 1
     fi
     if ! $TARGET-gcc -c -shared -fPIC $MAINDIR/scripts/dummyclib.c -o libc.so \
-         2>>$MAINLOGDIR/stderr.log >>$MAINLOGDIR/stdout.log
+         2>>$LOGDIR/stderr.log >>$LOGDIR/stdout.log
     then
         log_error "Failed to build dummy libc.so"
        return 1
@@ -485,7 +485,9 @@ prepare_binutils_src() {
            cd $MAINSRCDIR/binutils-$VERSION_BINUTILS && autoconf )) ||
      ! ( is_greater_version $VERSION_BINUTILS 2.18     ||
         (  patch_src binutils-$VERSION_BINUTILS binutils_printffix &&
-	   patch_src binutils-$VERSION_BINUTILS binutils_ignret ))
+	   patch_src binutils-$VERSION_BINUTILS binutils_ignret ))  ||
+     ! ( ! cmp_versions $VERSION_BINUTILS 2.20 ||
+         patch_src binutils-$VERSION_BINUTILS binutils_arm_empty_body )
   then
     log_error "Binutils setup failed"
     return 1
@@ -532,7 +534,7 @@ log_write 2 "Native tools: \"$NATIVE_PREFIX\""
 log_write 2 "Toolchain:    \"$PREFIX\""
 log_write 2 "Target:       \"$TARGET\""
 log_write 2 "Src:          \"$MAINSRCDIR\""
-log_write 2 "Log:          \"$MAINLOGDIR\""
+log_write 2 "Log:          \"$LOGDIR\""
 log_write 2 "Build:        \"$MAINBUILDDIR\""
 log_write 2 "Setup:        \"$SETUP\""
 log_write 2 "Versionset:   \"$VERSIONSET\""
@@ -560,6 +562,11 @@ then
   exit 1
 fi
 
+if test "x$LIBC_MODE" = "xglibc" || test "x$LIBC_MODE" = "xeglibc"
+then
+  E_GLIBC=yes
+fi
+
 if test "x$CROSSER_DOWNLOAD" = "xyes"
 then
   if ! ( cd $PACKETDIR && $MAINDIR/scripts/download_packets.sh "$STEPPARAM" )
@@ -590,7 +597,8 @@ if test "x$STEP_NATIVE" = "xyes" ; then
      ! unpack_component Python   $VERSION_PYTHON              ||
      ! build_for_host   Python   Python-$VERSION_PYTHON       ||
      ! unpack_component gtk-doc  $VERSION_GTK_DOC             ||
-     ! build_for_host   gtk-doc  gtk-doc-$VERSION_GTK_DOC     ||
+     ! build_for_host   gtk-doc  gtk-doc-$VERSION_GTK_DOC         \
+       "--disable-scrollkeeper"                                   ||
      ! unpack_component pkg-config $VERSION_PKG_CONFIG            ||
      ! build_for_host   pkg-config pkg-config-$VERSION_PKG_CONFIG ||
      ! prepare_binutils_src                                   ||
@@ -646,7 +654,7 @@ then
     fi
   fi
 
-  if test "x$BUILD" = "x$TARGET" && test "x$LIBC_MODE" = "xglibc"
+  if test "x$BUILD" = "x$TARGET" && test "x$E_GLIBC" = "xyes"
   then
     export PATH="$PATH_NATIVE:$PATH"
     hash -r
@@ -710,7 +718,7 @@ then
     fi
   fi
 
-  if test "x$LIBC_MODE" = "xglibc"
+  if test "x$E_GLIBC" = "xyes"
   then
 
     # Initial cross-compiler                                                                      
@@ -728,40 +736,76 @@ then
       exit
     fi
 
-    LIBCNAME=glibc
-    LIBCVER=$VERSION_GLIBC
-    LIBCDIR=$LIBCNAME-$LIBCVER
-
-    if ! unpack_component $LIBCNAME       $LIBCVER          ||
-       ! unpack_component $LIBCNAME-ports $LIBCVER $LIBCDIR
+    if test "x$LIBC_MODE" = "xeglibc"
     then
-      crosser_error "$LIBCNAME unpacking failed"
-      exit 1
+      # eglibc
+      LIBCNAME=eglibc
+      LIBCVER=$VERSION_EGLIBC
+      LIBCDIR=$LIBCNAME-$LIBCVER
+      if ! unpack_component $LIBCNAME $VERSION_EGLIBC_DEB
+      then
+        crosser_error "$LIBCNAME unpacking failed"
+        exit 1
+      fi
+      if ! ln -s $LIBCNAME $MAINSRCDIR/$LIBCDIR
+      then
+        crosser_error "Creation of $LIBCNAME links failed"
+        exit 1
+      fi
+      if ! ( is_greater_version $LIBCVER 2.9 ||
+             patch_src $LIBCDIR glibc_nomanual )           ||
+         ! ( is_smaller_version $LIBCVER 2.10.1 ||
+             patch_src $LIBCDIR eglibc2.10.1_nomanual )
+      then
+        crosser_error "$LIBCNAME patching failed"
+        exit 1
+      fi
+    else
+      # glibc
+      LIBCNAME=glibc
+      LIBCVER=$VERSION_GLIBC
+      LIBCDIR=$LIBCNAME-$LIBCVER
+      if ! unpack_component $LIBCNAME       $LIBCVER       ||
+         ! unpack_component $LIBCNAME-ports $LIBCVER $LIBCDIR
+      then
+        crosser_error "$LIBCNAME unpacking failed"
+        exit 1
+      fi
+      if ! ln -s $LIBCNAME-ports-$LIBCVER $MAINSRCDIR/$LIBCDIR/ports
+      then
+	crosser_error "Creation of $LIBCNAME links failed"
+        exit 1
+      fi
+      if ! patch_src $LIBCDIR glibc_binutils2.20
+      then
+        crosser_error "$LIBCNAME patching failed"
+        exit 1
+      fi
     fi
 
     if ! (is_minimum_version $LIBCVER 2.8 ||
-          patch_src $LIBCDIR glibc_upstream_finc)                                 ||
+          patch_src $LIBCDIR glibc_upstream_finc)                ||
        ! (is_minimum_version $LIBCVER 2.8 ||
-          patch_src $LIBCDIR/$LIBCNAME-ports-$LIBCVER glibc_ports_arm_docargs)    ||
+          patch_src $LIBCDIR/ports glibc_ports_arm_docargs)      ||
        ! (is_minimum_version $LIBCVER 2.8 ||
-          patch_src $LIBCDIR/$LIBCNAME-ports-$LIBCVER glibc_ports_arm_pageh_inc)  ||
-       ! patch_src $LIBCDIR/$LIBCNAME-ports-$LIBCVER glibc_ports_arm_tlsinc       ||
-       ! (is_smaller_version $LIBCVER 2.9 ||
-          patch_src $LIBCDIR/$LIBCNAME-ports-$LIBCVER glibc_upstream_arm_sigsetjmp)
+          patch_src $LIBCDIR/ports glibc_ports_arm_pageh_inc)    ||
+       ! patch_src $LIBCDIR/ports glibc_ports_arm_tlsinc         ||
+       ! (! cmp_versions $LIBCVER 2.9 ||
+          patch_src $LIBCDIR/ports glibc_upstream_arm_sigsetjmp)
     then
       crosser_error "$LIBCNAME patching failed"
       exit 1
     fi
 
-#    if ! autogen_component eglibc $VERSION_EGLIBC "autoconf"
-#    then
-#      crosser_error "Eglibc autogen failed"
-#      exit 1
-#    fi
+    if ! autogen_component $LIBCNAME $LIBCVER "autoconf"
+    then
+      crosser_error "$LIBCNAME autogen failed"
+      exit 1
+    fi
 
     log_write 1 "Installing initial $LIBCNAME headers"
     if ! build_glibc $LIBCNAME $LIBCDIR \
-           "--with-tls --enable-add-ons=$LIBCNAME-ports-$LIBCVER --disable-sanity-checks --with-sysroot=$SYSPREFIX --with-headers=$SYSPREFIX/usr/include" \
+           "--with-tls --enable-add-ons=ports --disable-sanity-checks --with-sysroot=$SYSPREFIX --with-headers=$SYSPREFIX/usr/include" \
            "install-headers install-bootstrap-headers=yes" "headers"
     then
       log_error "Failed to install initial $LIBCNAME headers"
@@ -784,7 +828,7 @@ then
     fi
 
     if ! build_glibc $LIBCNAME $LIBCDIR \
-             "--with-tls --with-sysroot=$SYSPREFIX --with-headers=$SYSPREFIX/usr/include --enable-add-ons=$LIBCNAME-ports-$LIBCVER,nptl" \
+             "--with-tls --with-sysroot=$SYSPREFIX --with-headers=$SYSPREFIX/usr/include --enable-add-ons=ports,nptl" \
              "all install"
     then
       crosser_error "Failed to build final $LIBCNAME"
@@ -850,7 +894,7 @@ then
   STEP="gtk"
   STEPADD="     "
 
-  if test "x$LIBC_MODE" != "xglibc"
+  if test "x$E_GLIBC" != "xyes"
   then
     log_write 1 "Step gtk not available for $LIBC_MODE based builds, skipping"
   else
@@ -900,7 +944,8 @@ then
          "libtoolize aclocal automake autoconf"                                          ||
        ! build_with_cross_compiler fontconfig                                            \
           fontconfig-$VERSION_FONTCONFIG                                                 \
-          "--prefix=/usr --with-freetype-config=$PREFIX/interm/bin/freetype-config --with-arch=$TARGET"
+          "--prefix=/usr --with-freetype-config=$PREFIX/interm/bin/freetype-config --with-arch=$TARGET" \
+          "install"
     then
       crosser_error "gtk+ chain build failed"
       exit 1
@@ -913,7 +958,7 @@ then
   STEP="sdl"
   STEPADD="     "
 
-  if test "x$LIBC_MODE" != "xglibc"
+  if test "x$E_GLIBC" != "xyes"
   then
     log_write 1 "Step sdl not available for $LIBC_MODE based builds, skipping"
   elif test "x$KERN_ARCH" = "xarm"
@@ -929,6 +974,7 @@ then
        ! patch_src svgalib-$VERSION_SVGALIB svgalib_arm_outsb             ||
        ! patch_src svgalib-$VERSION_SVGALIB svgalib_nostrip               ||
        ! patch_src svgalib-$VERSION_SVGALIB svgalib_glinc                 ||
+       ! patch_src svgalib-$VERSION_SVGALIB svgalib_round                 ||
        ! build_svgalib             svgalib svgalib-$VERSION_SVGALIB       \
           "clean install"                                                 ||
        ! unpack_component          SDL       $VERSION_SDL                 ||
