@@ -143,7 +143,12 @@ download_needed() {
   fi
   for STEP in $STEPLIST
   do
-    if belongs_to_step $2 $STEP ; then
+    if "x$2" = "xlibjpeg$VERSION_JPEG" ; then
+      BASENAME=libjpeg
+    else
+      BASENAME=$2
+    fi
+    if belongs_to_step $BASENAME $STEP ; then
       download_packet "$1" "$2" "$PACKVER" "$4"
       return $?
     fi
@@ -262,9 +267,15 @@ then
   fi
 fi
 
-if test -e $MAINDIR/mirrors.conf ; then
-  if ! . $MAINDIR/mirrors.conf ; then
-    echo "Problem in reading list of mirrors to use" >&2
+if test -e "$MAINDIR/mirrors.conf" ; then
+  MIRRORCONF="$MAINDIR/mirrors.conf"
+elif test -e "$HOME/.crosser.mirrors" ; then
+  MIRRORCONF="$HOME/.crosser.mirrors"
+fi
+
+if test "x$MIRRORCONF" != "x" ; then
+  if ! . "$MIRRORCONF" ; then
+    echo "Problem in reading list of mirrors to use from $MIRRORCONF" >&2
     exit 1
   fi
 fi
@@ -335,6 +346,7 @@ then
     libtool)  VERSION_LIBTOOL=$VERSION_SELECTED ;;
     mpfr)     VERSION_MPFR=$VERSION_SELECTED ;;
     Python)   VERSION_PYTHON=$VERSION_SELECTED ;;
+    libjpeg*) VERSION_JPEG=$(echo $VERSION_SELECTED | sed 's/-.*//') ;;
   esac
 fi
 GLIB_DIR="$(echo $VERSION_GLIB | sed 's/\./ /g' | (read MAJOR MINOR PATCH ; echo -n $MAJOR.$MINOR ))"
@@ -381,6 +393,8 @@ download_needed "$MIRROR_GNU/glibc/"    "glibc"    "$VERSION_GLIBC"    "tar.bz2"
 RET="$RET $?"
 download_needed "$MIRROR_GNU/glibc/"    "glibc-ports" "$VERSION_GLIBC" "tar.bz2"
 RET="$RET $?"
+download_needed "$MIRROR_DEB/pool/main/e/eglibc/"       "eglibc"     "$VERSION_EGLIBC_DEB" "dsc"
+RET="$RET $?"
 download_needed "$MIRROR_KERNEL/pub/linux/kernel/v2.6/" "linux" "$VERSION_KERNEL"  "tar.bz2"
 RET="$RET $?"
 download_needed "$MIRROR_SOURCEWARE/pub/newlib/"        "newlib" "$VERSION_NEWLIB" "tar.gz"
@@ -410,7 +424,7 @@ download_needed "$MIRROR_GNU/gettext/"                  "gettext"    "$VERSION_G
 RET="$RET $?"
 download_needed "$MIRROR_GNOME/sources/glib/$GLIB_DIR/" "glib"       "$VERSION_GLIB"       "tar.bz2"
 RET="$RET $?"
-download_needed "$MIRROR_DEB/pool/main/libj/libjpeg6b/" "libjpeg6b"  "$VERSION_JPEG"       "dsc"
+download_needed "$MIRROR_DEB/pool/main/libj/libjpeg$VERSION_JPEG/" "libjpeg$VERSION_JPEG"  "$VERSION_JPEG_DEB"       "dsc"
 RET="$RET $?"
 download_needed "ftp://ftp.remotesensing.org/pub/libtiff/" "tiff"    "$VERSION_TIFF"       "tar.gz"
 RET="$RET $?"
@@ -440,6 +454,8 @@ download_needed "http://www.libsdl.org/release/"        "SDL"        "$VERSION_S
 RET="$RET $?"
 download_needed "http://www.libsdl.org/projects/SDL_image/release/" "SDL_image"  "$VERSION_SDL_IMAGE"  "tar.gz"
 RET="$RET $?"
+download_needed "http://www.libsdl.org/projects/SDL_mixer/release/" "SDL_mixer"  "$VERSION_SDL_MIXER"  "tar.gz"
+RET="$RET $?"
 
 for VALUE in $RET
 do
